@@ -23,7 +23,7 @@
 #include "mtcompare_sumaclust.h"
 #include "sumaclust.h"
 
-#define VERSION "1.0.20"
+#define VERSION "1.0.31"
 
 
 /* ----------------------------------------------- */
@@ -585,7 +585,7 @@ void putSeqInCluster(fastaSeqPtr* seq, fastaSeqPtr* center, double score)
 }
 
 
-int compare(fastaSeqPtr* db,  int n, BOOL fastOption, double threshold, BOOL normalize, int reference, BOOL lcsmode,
+int compare(fastaSeqPtr* db, int n, BOOL fastOption, double threshold, BOOL normalize, int reference, BOOL lcsmode,
 		double max_ratio)
 {
 	double       score;
@@ -723,7 +723,7 @@ int compare(fastaSeqPtr* db,  int n, BOOL fastOption, double threshold, BOOL nor
 	free(iseq1-sizeForSeqs+lmax);
 	free(iseq2-sizeForSeqs+lmax);
 
-	if (normalize && reference == ALILEN)
+	if (normalize && (reference == ALILEN))
 		free(address);
 
 	return(k);
@@ -1037,7 +1037,6 @@ int main(int argc, char** argv)
 	// FASTA file
 	if (printFASTA)
 	{
-
 		if (printFASTAtofile)
 		{
 			FASTA_output = fopen(FASTA_file_name, "w");
