@@ -458,6 +458,9 @@ int calculateSizeToAllocate(int maxLen, int minLen, int LCSmin)
 
 	calculateBandLengths(maxLen, minLen, &notUsed, &size, LCSmin);		// max size = max left band length * 2
 
+	if (!size)	// Happens if there is no threshold (threshold is 100% similarity) and generates bugs if left to 0
+		size = 1;
+
 	//fprintf(stderr, "\nsize for address before %8 = %d", size);
 
 	size*= 2;
